# ESTM 60203 Introduction to Applied Operations Research #

## Catalog Description ##

Introduction to the applications of operations research including blending problems, scheduling, project management, performance analysis, supply chains, job shops, and inventory management. Through case studies, students will learn how to use available optimization tools to solve problems arising in operations management. Special emphasis will be given to the role of uncertainty and risk in business operations.

## Topics #

The Operations Management component of the ESTEEM program will be taught in a series of fourteen 75 minute classroom discussions. Coverage will correspond to the topics listed below, with relative emphasis and additional topics dependent on student interest.

### 0. Overview of Operations Research in Business Operations (1 session) ###

### 1. Maximizing Profits (2 sessions) ###

* What is optimization and mathematical programming? 
* Linear objectives, decision variables, constraints, 'reduced' costs and 'shadow' prices. 
* The vital information that optimization can give you.

### 2. Modeling Business Decisions (2 sessions) ###

* Elements of modeling business decisions.
* Mixing, assignment, transportation, flow, and other commons paradigm for business decisions.  

### 3. Planning and Scheduling (2 sessions) ###

* Flow Shops
* Critical Path Method, PERT, and Critical Chain methods for project management
* Sequencing Tasks and Jobs for bottleneck operations

### 4. Understanding Supply Chain Dynamics (2 sessions) ###

* Inventory Management, Economic Order Quantity
* Supply chain dynamics and the role of information (Beer Game Simulation)
* Direct simulation of warehouse, manufacturing, and other business operations.

### 5. Techniques for Managing Uncertainty and Risk (4 sessions) ###

* Recourse decisions, the newsvendor problem, and why there are after-Christmas sales
* Decision Trees
* Modeling Aversion to Risk with Utility Functions
* Log-Optimal Growth
* Stochastic Price Models
* Real Options Analysis

## Instructor ##

**Instructor:**  Jeffrey Kantor

**Office Hours:** 1:30-4pm Thursdays, 176 Fitzpatrick Hall. These are the regularly scheduled office hours. I’m generally available during regular business hours for appointments by email, phone, or text.

**Contact Information:** 

* [Kantor.1@nd.edu](mailto:Kantor.1@nd.edu) -- *this is the best way to reach me*
*  574-699-3525 (Google Voice) / 574-532-4233 (Mobile) / 574-631-5797 (Office) 

## Calendar ##

| Date | Topic | Case Study Due|
| - | - | - |
| Mon, Mar 14 | Overview | |
| Wed, Mar 16 | Maximizing Profits Part 1. | |
| Mon, Mar 21 | Maximizing Profits Part 2. | Landhills Winery|
| Wed, Mar 23 | Modeling Business Decisions Part 1.| |
| Wed, Mar 30 | Modeling Business Decisions Part 2.| DHL Supply Chain |
| Mon, Apr 4 | Planning and Scheduling Part 1. | |
| Wed, Apr 6 | Planning and Scheduling Part 2. | MS Bicycle Tour | 
| Mon, Apr 11 | Supply Chain Dynamics Part 1. | |
| Wed, Apr 13 | Supply Chain Dynamics Part 2. | Beer Game Simulation |
| Mon, Apr 18 | Uncertainty and Risk Part 1. | |
| Wed, Apr 20 | Uncertainty and Risk Part 2. | |
| Mon, Apr 25 | Uncertainty and Risk Part 3. | "Fortune's Formula" |
| Wed, Apr 27 | Uncertainty and Risk Part 4. | |

## Required Materials ##

### Materials to Purchase

Every effort has been made to keep the tailor the materials to the topics in the course, and to avoid unneed expense. The following coursepack should be purchased by all students --

* A course pack consisting of five case studies and one supply chain simulation is available from the Harvard Business School Press. Use this link [https://cb.hbsp.harvard.edu/cbmp/access/32129411](https://cb.hbsp.harvard.edu/cbmp/access/32129411) to order the course pack. The course pack is delivered electronicall with an option to order a paper copy of the case studies.

These two books are popularized accounts of key topics that will be discussed in the course. These are inexpensive (especially in ebook form), relatively quick reads, that will add to your understanding of the course material.

* Andreas Scherer. *Be Fast or Be Gone: Racing the Clock with Critical Chain Project Management*, 234 pages, Prochain Solutions Inc, 2011. (Available from [Amazon](http://www.amazon.com/Be-Fast-Gone-Critical-Management/dp/1934979074).)

* William Poundstone. *Fortune's Formula: The Untold Story of the Scientific Betting System That Beat the Casinos and Wall Street*,  Hill and Wang, 2008. (Available from [Amazon](http://www.amazon.com/Fortunes-Formula-Scientific-Betting-Casinos-ebook/dp/B000SBTWNC/ref=pd_sim_kstore_4?ie=UTF8&refRID=0BWSMTMXW8037RE9ATZR))

This book is highly recommended for those who wish to apply linear optimization tools to real-world business problems. The text, now in its fifth edition, was developed by a professor at the London School of Economics, and is one of the most widely known books its kind.

* H. Paul Williams. [*Model Building in Mathematical Programming*](http://www.wiley.com/WileyCDA/WileyTitle/productCd-1118443330.html), 5th Edition, 432 pages, Wiley, 2013. (Available from [Amazon](http://www.amazon.com/Model-Building-Mathematical-Programming-Williams-ebook/dp/B00B8Y6MIG%3FSubscriptionId%3D14BJ8ZEX3WNZS76SDCG2%26tag%3Dwwwwileycom-20%26linkCode%3Dxm2%26camp%3D2025%26creative%3D165953%26creativeASIN%3DB00B8Y6MIG).)

All other course materials available through Hesburgh library or on-line.

### Software ##

A key objective of this course is to provide students with the skills necessary to formulate and solve problems in operations management.  This objective is facilitated if students have individual access to software tools for implementation.

* **IPython.** Many of the course topics will be illustrated with examples coded and made available in the form of [IPython notebooks](http://jckantor.github.io/ESTM60203/).
* **GLPK/MathProg.** GLPK/MathProg is provides open source implementation of AMPL, an industry standard  language for operations and decisions. This course will use a [unique, web-based implementation](http://www3.nd.edu/~jeff/mathprog/mathprog.html) to facilitate learning and subsequent applications development.



### Supplementary Materials ##

<!---
 Case Studies:

* [Merton Truck Co., Harvard Business School Case Study 189163-PDF-ENG](http://hbr.org/product/merton-truck-co/an/189163-PDF-ENG)
* [Australian Motors Ltd., Harvard Business School Case Study OIT23-PDF-ENG](http://hbr.org/product/australian-motors-ltd/an/OIT23-PDF-ENG)
* [Optimization Modeling Exercises, Harvard Business School Case Study UV0432-PDF-ENG](http://hbr.org/product/optimization-modeling-exercises/an/UV0432-PDF-ENG)
* Janice H. Hammond. "[Beer Game: Board Version](https://cb.hbsp.harvard.edu/cbmp/product/694104-PDF-ENG)," 9 pages, HBS Case Study 905D14-PDF-ENG, revised Oct 27, 1999.
* [Introduction to Real Options](https://cb.hbsp.harvard.edu/cbmp/product/905N15-PDF-ENG)
* [Investment Opportunities as Real Options: Getting Started on the Numbers](https://cb.hbsp.harvard.edu/cbmp/product/98404-PDF-ENG)

Other Materials:
 
* Goldratt, Eliyahu M.; Jeff Cox. [*The Goal: A Process of Ongoing Improvement.*](http://www.amazon.com/Goal-Eliyahu-M-Goldratt/dp/0884271951) Great Barrington, MA.: North River Press. ISBN 0-88427-061-0.
* [The Beer Game](http://www.beergame.org/).  Teaching experiences are described [here.](https://domino.fov.uni-mb.si/proceedings.nsf/. 0/5ee189e0c08b6a98c1257482003c58d5/$FILE/45Riemer.pdf)
-->

* Robert J. Vanderbei, *Linear Programming: Foundations and Extentions*, Springer, 2008. (Available to Notre Dame students and faculty through the e-book resources of Hesburgh Library.)
* Lectures on Linear Programming
	* Gilbert Strang: [Linear Programming and Duality](http://www.academicearth.org/lectures/linear-programming-and-duality)
* Arthur V. Hill, "[The Newvendor Problem](http://www.clamshellbeachpress.com/downloads/newsvendor_problem.pdf)," Clamshell Beach Press, CBP WP 57-23, 2011. (Available as a free download from Clamshell Beach Press.)
* [Applications of Optimization with Xpress-MP](http://www3.ntu.edu.sg/home/bernhard/lp/lp_book.pdf) by Christelle Gueret, Christian Prins, and Marc Sevaux. Translated and revised by Susanne Heipcke. Published in 2002 by Dash Optimization, ISBN 0-9543503-0-8. Available from Amazon.com.
* Other Links
	* [Dick Barr's Operations Research Toolkit](http://lyle.smu.edu/~barr/ortoolkit/)
	* [J E Beasley's OR-Notes](http://people.brunel.ac.uk/~mastjjb/jeb/or/contents.html)
	* [AMPL: A Modeling Language for Mathematical Programming](http://www.ampl.com/BOOK/download.html) Chapters are free for download.

## Assignments ##

Assignments are integral part of the learning experience. Students will develop and solve models for case studies,

## Learning Outcomes

This module provides an overview of selected concepts in Applied Operations Research. The course is organized around a general theme of modeling and optimization for process operations, with the main attention on techniques for modeling and solving problems in process operations, managing complex systems of activities, and understanding the role of uncertainty in capital allocation and planning.

Students completing this module will be able to:

1. Formulate, model in a mathematical programming language, and compute solutions for small to medium scale applications of linear programming in process operations, including binary and integer decision variables.
2.  and solve network, transportation, and related logistics optimization problems of small to medium scale.
3. Prepare a critical path analysis for medium scale projects, identify the critical path, find earliest finish times and latest start times.
4. Analyze job shop and flow shop performance for deterministic conditions under common prioritization schedules, including FIFO, LIFO, EDD, and SDT.
5. Calculate optimal schedules for job and flow shops under deterministic constraints.
6. Formulate and solve capital allocation problem using mean/variance analysis of return and risk.
7. Calculate optimal inventories using two-stage stochastic decision models with recourse.
8. Prepare decision trees and solve for expected mean value, expected value of perfect information.
9. Analyze case studies using selected tools from Operations Research.

## Grading ##

A grade will be assigned based on in-class participation and performance on case study projects and final project. Case studies and final project will be turned for grading via the Sakai course management system.  Components grades will be on a 5-10 point scale (10-20 for the final project), totaled, and adjusted based on class participation to determine a course letter grade.
